lcvtoolbox.core.schemas.PoseRPYSchema
=====================================

.. currentmodule:: lcvtoolbox.core.schemas

.. autoclass:: PoseRPYSchema
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~PoseRPYSchema.__init__
      ~PoseRPYSchema.construct
      ~PoseRPYSchema.copy
      ~PoseRPYSchema.dict
      ~PoseRPYSchema.from_list
      ~PoseRPYSchema.from_orm
      ~PoseRPYSchema.from_pose_rpy
      ~PoseRPYSchema.from_transformation_matrix
      ~PoseRPYSchema.json
      ~PoseRPYSchema.model_construct
      ~PoseRPYSchema.model_copy
      ~PoseRPYSchema.model_dump
      ~PoseRPYSchema.model_dump_json
      ~PoseRPYSchema.model_json_schema
      ~PoseRPYSchema.model_parametrized_name
      ~PoseRPYSchema.model_post_init
      ~PoseRPYSchema.model_rebuild
      ~PoseRPYSchema.model_validate
      ~PoseRPYSchema.model_validate_json
      ~PoseRPYSchema.model_validate_strings
      ~PoseRPYSchema.parse_file
      ~PoseRPYSchema.parse_obj
      ~PoseRPYSchema.parse_raw
      ~PoseRPYSchema.schema
      ~PoseRPYSchema.schema_json
      ~PoseRPYSchema.to_list
      ~PoseRPYSchema.to_numpy
      ~PoseRPYSchema.to_point3d
      ~PoseRPYSchema.to_pose_rpy
      ~PoseRPYSchema.to_rpy_radians
      ~PoseRPYSchema.to_transformation_matrix
      ~PoseRPYSchema.update_forward_refs
      ~PoseRPYSchema.validate
      ~PoseRPYSchema.validate_finite
      ~PoseRPYSchema.validate_pitch
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PoseRPYSchema.model_computed_fields
      ~PoseRPYSchema.model_config
      ~PoseRPYSchema.model_extra
      ~PoseRPYSchema.model_fields
      ~PoseRPYSchema.model_fields_set
      ~PoseRPYSchema.x
      ~PoseRPYSchema.y
      ~PoseRPYSchema.z
      ~PoseRPYSchema.roll
      ~PoseRPYSchema.pitch
      ~PoseRPYSchema.yaw
   
   